@@ -24,7 +24,7 @@ newtype ChModuleName = ChModuleName String
     deriving (Eq, Ord, Read, Show, Generic)
 
 data ChComponentName = ChSetupHsName
-                     | ChLibName
+                     | ChLibName String
                      | ChExeName String
                      | ChTestName String
                      | ChBenchName String
